@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_core.h 711 2004-05-14 14:56:58Z roms $ */
+/* $Id: tilp_core.h 1125 2005-05-24 18:09:19Z julien $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -101,6 +101,8 @@ extern "C" {
   int tilp_screen_capture(void);
   uint8_t *tilp_screen_convert(void);
   uint8_t *tilp_screen_blurry(void);
+  gboolean tilp_screen_write_eps(const gchar *filename, GError **error);
+  gboolean tilp_screen_write_pdf(const gchar *filename, GError **error);
 
   // tilp_misc.c
 #ifndef __MACOSX__
